@@ -43,13 +43,13 @@ class KDEVPYTHONDUCHAIN_EXPORT DeclarationBuilder: public DeclarationBuilderBase
 {
 public:
     DeclarationBuilder(PythonEditorIntegrator* editor, int ownPriority);
-    virtual ~DeclarationBuilder();
+    ~DeclarationBuilder() override;
 
     /**
      * @brief Entry function, called by KDevPlatform.
      */
     ReferencedTopDUContext build(const IndexedString& url, Ast* node,
-                                 ReferencedTopDUContext updateContext = ReferencedTopDUContext()) override;
+                                 const ReferencedTopDUContext& updateContext = ReferencedTopDUContext()) override;
 
     /**
      * @brief Set whether the current running pass is the first or the second one.
@@ -117,7 +117,7 @@ protected:
     template<typename T> T* visitVariableDeclaration(Python::Ast* node, Declaration* previous=nullptr,
                                                      AbstractType::Ptr type = AbstractType::Ptr(),
                                                      VisitVariableFlags flags=NoVisitVariableFlags);
-    template<typename T> T* visitVariableDeclaration(Identifier* node, Ast* originalAst = 0, Declaration* previous=nullptr,
+    template<typename T> T* visitVariableDeclaration(Identifier* node, Declaration* previous=nullptr,
                                                      AbstractType::Ptr type = AbstractType::Ptr(),
                                                      VisitVariableFlags flags=NoVisitVariableFlags);
 
@@ -207,8 +207,7 @@ protected:
      * @brief python-specific version of openDeclaration which scans for existing declarations in previous versions of
      *        this top-context in a more intelligent way.
      * Use this in normal declaratonbuilder code if you can't use visitVariableDeclaration. */
-    template<typename T> T* eventuallyReopenDeclaration(Python::Identifier* name, Python::Ast* range,
-                                                        FitDeclarationType mustFitType);
+    template<typename T> T* eventuallyReopenDeclaration(Python::Identifier* name, FitDeclarationType mustFitType);
 
     template<typename T> QList<Declaration*> reopenFittingDeclaration(QList<Declaration*> declarations,
                                                                       FitDeclarationType mustFitType,
@@ -224,7 +223,7 @@ protected:
      * @return :Declaration* the declaration created, or 0 if none was found.
      **/
     Declaration* createModuleImportDeclaration(QString dottedName, QString declarationName, Python::Identifier* declarationIdentifier,
-                                               ProblemPointer& problemEncountered, Python::Ast* rangeNode = 0);
+                                               ProblemPointer& problemEncountered, Python::Ast* rangeNode = nullptr);
     /**
      * @brief Create a tree of declarations for the specified list.
      * Give the list ["foo","bar","baz"], and you'll get a declaration "foo" containing "bar" in its internal context,
@@ -239,11 +238,11 @@ protected:
      * @param declarationIdentifier provides the name and range
      * @param innerCtx the internalContext() to set on the last created declaration. Either this or aliasDeclaration must be provided!
      * @param aliasDeclaration the declaration to alias with the last created declaration
-     * @param rangeNode can be used to override the declarationIdentifier's range, if required. Defaults to 0.
+     * @param range can be used to override the declarationIdentifier's range, if required. Defaults to an invalid range.
      * @return :Declaration* the top level declaration created
      **/
     Declaration* createDeclarationTree(const QStringList& nameComponents, Identifier* declarationIdentifier,
-                                       const ReferencedTopDUContext& innerCtx, Declaration* aliasDeclaration = 0,
+                                       const ReferencedTopDUContext& innerCtx, Declaration* aliasDeclaration = nullptr,
                                        const RangeInRevision& range = RangeInRevision::invalid());
 
     /**
@@ -259,16 +258,10 @@ protected:
     Declaration* findDeclarationInContext(QStringList dottedNameIdentifier, TopDUContext* ctx) const;
 
 private:
-    template<class T> T* openDeclaration(Identifier* name, Ast* range, DeclarationFlags flags = NoFlags)
+    template<class T> T* openDeclaration(Identifier* name, DeclarationFlags flags = NoFlags)
     {
-        T* decl = DeclarationBuilderBase::openDeclaration<T>(name, range, flags);
-        decl->setAlwaysForceDirect(true);
-        return decl;
-    };
-    template<class T> T* openDeclaration(const QualifiedIdentifier& id, const RangeInRevision& newRange,
-                                         DeclarationFlags flags = NoFlags)
-    {
-        T* decl = DeclarationBuilderBase::openDeclaration<T>(id, newRange, flags);
+        T* decl = DeclarationBuilderBase::openDeclaration<T>(KDevelop::Identifier(name->value),
+                                                             editorFindRange(name, name), flags);
         decl->setAlwaysForceDirect(true);
         return decl;
     };
